@@ -163,10 +163,10 @@ def moveInHaving(inner, outer, debug=False):
         
         # get rid of references that were only there to provide for the aggregate joincond (broken)
         # if delete:
-        for key, inexpr in inner.columns.items():
-            # if the expr doesn't get refered to by the outer table
-            if inexpr in havingexpr.descendants() and not outer.allDescendants().filter(lambda x: x.getRef() == inexpr).exists():
-                del inner.columns[key]
+        # for key, inexpr in inner.columns.items():
+        #     # if the expr doesn't get refered to by the outer table
+        #     if inexpr in havingexpr.descendants() and not inner.parents.bind(lambda x: x.allDescendants()).filter(lambda x: x.getRef() == inexpr).exists():
+        #         del inner.columns[key]
 
 
 def moveInAll(inner, outer, debug=False):
@@ -470,12 +470,12 @@ def mergeGrouped(self, debug=False, subquery=False):
     for tablegroup in alltablegroups:
         
         merged = tablegroup.fold(lambda x, y: x @ y)
-        # if self not in tablegroup:
+        
         self.setSource(merged, oldtable=tablegroup)
         
         if self in tablegroup:
             
-            moveInHaving(inner=merged, outer=self)
+            # moveInHaving(inner=table, outer=self)
             
             # merge with a subquery and convert the agg exprs
             merged.modify(lambda x: mergeExpr(x, oldtables=tablegroup))
